<template>
  <div class="p-4 border rounded bg-white shadow-sm w-100">
    <!-- هدر ماه -->
    <div class="d-flex justify-content-between align-items-center mb-4">
      <button @click="prevMonth" class="btn btn-outline-secondary btn-sm">
        <i class="icon icon-filled-angle-right font-size-10 align-middle"></i>
        ماه قبل
      </button>
      <h2 class="h6 mb-0">{{ currentMonthName }} {{ currentYear }}</h2>
      <button @click="nextMonth" class="btn btn-outline-secondary btn-sm">
        ماه بعد
        <i class="icon icon-filled-angle-left font-size-10 align-middle"></i>
      </button>
    </div>

    <!-- روزهای هفته -->
    <div class="row text-center fw-bold mb-2">
      <div v-for="(day, idx) in weekDays" :key="'weekday-' + idx" class="col">
        {{ day }}
      </div>
    </div>

    <!-- بدنه تقویم -->
    <div v-for="(week, weekIdx) in weeks" :key="'week-' + weekIdx" class="row text-center mb-1">
      <div
          v-for="(dateObj, dateIdx) in week"
          :key="'day-' + dateIdx + '-' + weekIdx"
          class="col p-1 d-flex justify-content-center"
      >
        <button
            v-if="dateObj.date"
            class="date-btn btn w-100"
            :class="[
            isInRange(dateObj.date) ? 'btn-in-range' :
            !dateObj.isCurrentMonth ? 'btn-other-month' :
            getDisableLabel(dateObj.date) ? 'btn-disabled' :
            isToday(dateObj.date) ? 'btn-today' :
            'btn-available'
          ]"
            @click="selectDate(dateObj.date)"
            :disabled="!!getDisableLabel(dateObj.date)"
        >
          <span v-if="getDisableLabel(dateObj.date)" class="small">
            {{ getDisableLabel(dateObj.date) }}
          </span>
          <span v-else>
            {{ dateObj.day }}
          </span>
        </button>
        <div v-else class="date-placeholder"></div>
      </div>
    </div>
  </div>
</template>

<script setup>
import { ref, computed } from 'vue'
import dayjs from 'dayjs'
import jalaliday from 'jalaliday'
dayjs.extend(jalaliday)
dayjs.calendar('jalali')

const emit = defineEmits(['update:modelValue'])

const props = defineProps({
  modelValue: {
    type: Object,
    default: () => ({ from_date: '', to_date: '' })
  },
  minDate: String,
  maxDate: String,
  disableDates: {
    type: Array,
    default: () => []
  }
})

const today = dayjs()
const currentMonth = ref(today.month())
const currentYear = ref(today.year())
const startDate = ref(null)
const endDate = ref(null)

const weekDays = ['ش', 'ی', 'د', 'س', 'چ', 'پ', 'ج']

function updateModel() {
  let days_count = 0
  if (startDate.value && endDate.value) {
    days_count = endDate.value.diff(startDate.value, 'day') + 1
  } else if (startDate.value) {
    days_count = 1
  }
  emit('update:modelValue', {
    from_date: startDate.value ? startDate.value.format('YYYY-MM-DD') : '',
    to_date: endDate.value ? endDate.value.format('YYYY-MM-DD') : '',
    days_count
  })
}

const weeks = computed(() => {
  const firstDayOfMonth = dayjs().year(currentYear.value).month(currentMonth.value).date(1)
  const daysInMonth = firstDayOfMonth.daysInMonth()
  const startWeekDay = (firstDayOfMonth.day() + 2) % 7

  const allDays = []

  // روزهای ماه قبل
  const prevMonth = firstDayOfMonth.subtract(1, 'month')
  const prevMonthDays = prevMonth.daysInMonth()
  for (let i = startWeekDay - 1; i >= 0; i--) {
    const date = prevMonth.date(prevMonthDays - i)
    allDays.push({ day: date.calendar('jalali').date(), date, isCurrentMonth: false })
  }

  // روزهای ماه جاری
  for (let i = 1; i <= daysInMonth; i++) {
    const date = dayjs().year(currentYear.value).month(currentMonth.value).date(i)
    allDays.push({ day: i, date, isCurrentMonth: true })
  }

  // روزهای ماه بعد برای پر کردن ردیف
  const totalCells = allDays.length
  const nextMonth = firstDayOfMonth.add(1, 'month')
  let extraDays = 0
  while ((totalCells + extraDays) % 7 !== 0) extraDays++
  for (let i = 1; i <= extraDays; i++) {
    const date = nextMonth.date(i)
    allDays.push({ day: i, date, isCurrentMonth: false })
  }

  const weekList = []
  for (let i = 0; i < allDays.length; i += 7) {
    weekList.push(allDays.slice(i, i + 7))
  }

  return weekList
})

function prevMonth() {
  if (currentMonth.value === 0) {
    currentMonth.value = 11
    currentYear.value--
  } else {
    currentMonth.value--
  }
}

function nextMonth() {
  if (currentMonth.value === 11) {
    currentMonth.value = 0
    currentYear.value++
  } else {
    currentMonth.value++
  }
}

function getDisableLabel(date) {
  if (!date) return null
  const formatted = date.calendar('jalali').format('YYYY/MM/DD')
  const found = props.disableDates.find(d => d.date === formatted)
  return found ? found.label : null
}

function isToday(date) {
  return date.isSame(today, 'day')
}

function selectDate(date) {
  if (!date || getDisableLabel(date)) return

  if (!startDate.value || (startDate.value && endDate.value)) {
    startDate.value = date
    endDate.value = null
  } else if (date.isAfter(startDate.value)) {
    if (hasDisabledInRange(startDate.value, date)) {
      startDate.value = date
      endDate.value = null
    } else {
      endDate.value = date
    }
  } else {
    startDate.value = date
    endDate.value = null
  }

  updateModel()
}

function hasDisabledInRange(start, end) {
  let current = start
  while (current.isBefore(end)) {
    current = current.add(1, 'day')
    if (getDisableLabel(current)) return true
  }
  return false
}

function isInRange(date) {
  if (!date) return false
  if (startDate.value && !endDate.value) return date.isSame(startDate.value, 'day')
  if (startDate.value && endDate.value)
    return (
        (date.isAfter(startDate.value) || date.isSame(startDate.value)) &&
        (date.isBefore(endDate.value) || date.isSame(endDate.value))
    )
  return false
}

const currentMonthName = computed(() => {
  const months = ['فروردین', 'اردیبهشت', 'خرداد', 'تیر', 'مرداد', 'شهریور',
    'مهر', 'آبان', 'آذر', 'دی', 'بهمن', 'اسفند']
  return months[currentMonth.value]
})
</script>

<style scoped>
.date-btn {
  height: 50px;
  font-size: 16px;
  line-height: 50px;
  padding: 0;
  border-radius: 8px;
  transition: all 0.3s ease;
  display: flex;
  align-items: center;
  justify-content: center;
}

.date-placeholder {
  width: 100%;
  height: 50px;
}

.date-btn span {
  width: 100%;
  text-align: center;
  display: inline-block;
}

/* روزهای قابل انتخاب */
.btn-available {
  border: 1px solid #ff9800;
  color: #ff9800;
  background-color: #fff;
}

.btn-available:hover {
  background-color: #ff9800;
  color: #fff;
}

/* روز امروز */
.btn-today {
  border: 1px solid #dc3545;
  color: #dc3545;
  background-color: #fff;
}

/* روزهای در بازه انتخاب */
.btn-in-range {
  background-color: #ff9800;
  color: white;
  border: 1px solid #ff9800;
}

/* روزهای غیرفعال */
.btn-disabled {
  background-color: #e9ecef;
  color: #6c757d;
  font-size: 12px;
  cursor: not-allowed;
  border: 1px solid #ccc;
}

/* روزهای ماه غیر جاری */
.btn-other-month {
  background-color: #f8f9fa;
  color: #adb5bd;
  border: 1px solid #dee2e6;
  font-size: 14px;
}
</style>
